@@ -11,7 +11,6 @@ import gobject
 gobject.threads_init()
 
 import gtk, gnomeapplet
-
 import getopt, sys
 from os.path import *
 
@@ -24,11 +23,11 @@ if _check(name):
 	print 'Running uninstalled deskbar, modifying PYTHONPATH'
 	sys.path.insert(0, abspath(name))
 else:
-	sys.path.insert(0, abspath("@PYTHONPATH@"))
-	print "Running installed deskbar, using [@PYTHONPATH@:$PYTHONPATH]"
+	sys.path.insert(0, abspath("@PYTHONDIR@"))
+	print "Running installed deskbar, using [@PYTHONDIR@:$PYTHONPATH]"
 
 # Now the path is set, import our applet
-import deskbar, deskbar.applet, deskbar.defs
+import deskbar, deskbar.DeskbarApplet, deskbar.defs
 
 import gettext, locale
 gettext.bindtextdomain('deskbar-applet', abspath(join(deskbar.defs.DATA_DIR, "locale")))
@@ -37,9 +36,11 @@ gettext.textdomain('deskbar-applet')
 locale.bindtextdomain('deskbar-applet', abspath(join(deskbar.defs.DATA_DIR, "locale")))
 locale.textdomain('deskbar-applet')
 
+import gtkexcepthook
+
 def applet_factory(applet, iid):
 	print 'Starting Deskbar instance:', applet, iid
-	deskbar.applet.DeskbarApplet(applet)
+	deskbar.DeskbarApplet.DeskbarApplet(applet)
 	return True
 
 # Return a standalone window that holds the applet
@@ -50,6 +51,7 @@ def build_window():
 	app.set_property('resizable', False)
 	
 	applet = gnomeapplet.Applet()
+	applet.get_orient = lambda: gnomeapplet.ORIENT_DOWN
 	applet_factory(applet, None)
 	applet.reparent(app)
 		
@@ -64,16 +66,17 @@ $ deskbar-applet [OPTIONS]
 
 OPTIONS:
 	-h, --help			Print this help notice.
-	-d, --debug			Enable debug output (default=off).
 	-w, --window		Launch the applet in a standalone window for test purposes (default=no).
+	-c, --cuemiac		Launch the Cuemiac UI (when in window mode) (default=no).
 	"""
 	sys.exit()
 	
 if __name__ == "__main__":	
 	standalone = False
+	cuemiac = False
 	
 	try:
-		opts, args = getopt.getopt(sys.argv[1:], "hdw", ["help", "debug", "window"])
+		opts, args = getopt.getopt(sys.argv[1:], "hwc", ["help", "window", "cuemiac"])
 	except getopt.GetoptError:
 		# Unknown args were passed, we fallback to bahave as if
 		# no options were passed
@@ -83,12 +86,17 @@ if __name__ == "__main__":
 	for o, a in opts:
 		if o in ("-h", "--help"):
 			usage()
-		elif o in ("-d", "--debug"):
-			print "No problems so far."
 		elif o in ("-w", "--window"):
 			standalone = True
+		elif o in ("-c", "--cuemiac"):
+			cuemiac = True
 			
 	if standalone:
+		if cuemiac:
+			deskbar.UI_OVERRIDE = deskbar.CUEMIAC_UI_NAME
+		else:
+			deskbar.UI_OVERRIDE = deskbar.COMPLETION_UI_NAME
+
 		import gnome
 		gnome.init(deskbar.defs.PACKAGE, deskbar.defs.VERSION)
 		build_window()
@@ -104,3 +112,4 @@ if __name__ == "__main__":
 	if PROFILE:
 		statprof.stop()
 		statprof.display()
+
